import {
  createContext,
  useCallback,
  useContext,
  useLayoutEffect,
  useState
} from "react";
import i18nTextData from "virtual-i18n-text";
import { flushSync } from "react-dom";
const DataContext = createContext({});
const ThemeContext = createContext({});
function usePageData() {
  const ctx = useContext(DataContext);
  return ctx.data;
}
function useLang() {
  const ctx = useContext(DataContext);
  return ctx.data.page.lang || "";
}
function useVersion() {
  const ctx = useContext(DataContext);
  return ctx.data.page.version || "";
}
function useDark() {
  const ctx = useContext(ThemeContext);
  return ctx.theme === "dark";
}
function useI18n() {
  const lang = useLang();
  return useCallback((key) => i18nTextData[key][lang], [lang]);
}
function useViewTransition(dom) {
  const [element, setElement] = useState(dom);
  useLayoutEffect(() => {
    if (document.startViewTransition && element !== dom) {
      document.startViewTransition(() => {
        flushSync(() => {
          setElement(dom);
        });
        window.dispatchEvent(new Event("RspressReloadContent"));
      });
    } else {
      flushSync(() => {
        setElement(dom);
      });
      window.dispatchEvent(new Event("RspressReloadContent"));
    }
  }, [dom]);
  return element;
}
export {
  DataContext,
  ThemeContext,
  useDark,
  useI18n,
  useLang,
  usePageData,
  useVersion,
  useViewTransition
};
